@@ -38,12 +38,12 @@ knit_print.tinytable <- function(x,
 }
 
 
-#' Print a tinytable to console or in an HTML viewer pane
+#' Print, display, or convert a tinytable object
 #' 
 #' This function is called automatically by `R` whenever a `tinytable` object is anprinted to the console or in an HTML viewer pane.
 #' 
 #' @inheritParams tt
-#' @param output format in which a Tiny Table is printed: `NULL` or one of `"latex"`, `"markdown"`, `"html"`, `"typst"`. If `NULL`, the output is chosen based on these rules:
+#' @param output format in which a Tiny Table is printed: `NULL` or one of `"latex"`, `"markdown"`, `"html"`, `"typst"`, `"dataframe"`. If `NULL`, the output is chosen based on these rules:
 #' + When called from a script in non-interactive mode, the default is "markdown" (`interactive() == FALSE`).
 #' + When called interactively in RStudio, the default is to display an HTML table in the viewer pane.
 #' + When called interactively in another development environment, the default is "markdown". 
@@ -59,7 +59,7 @@ print.tinytable <- function(x,
   if (is.null(output)) {
     output <- x@output
   } else {
-    assert_choice(output, c("latex", "markdown", "html", "typst"))
+    assert_choice(output, c("latex", "markdown", "html", "typst", "dataframe"))
   }
 
   if (output == "html") {
@@ -84,13 +84,18 @@ print.tinytable <- function(x,
     if (isTRUE(check_dependency("rstudioapi")) && rstudioapi::isAvailable()) {
       rstudioapi::viewer(htmlFile)
     } else if (interactive()) {
+      msg <- "Please choose a default browser with:
+
+      options(browser = 'firefox')
+      "
+      if (isTRUE(getOption("browser") == "")) stop(msg, call. = FALSE)
       utils::browseURL(htmlFile)
     } else {
       cat(tab, "\n")
     }
 
   } else {
-    stop("here be dragons")
+    return(x@table_dataframe)
   }
 
   return(invisible(x))
@@ -99,4 +104,4 @@ print.tinytable <- function(x,
 
 setMethod("show", "tinytable", function(object) {
   print.tinytable(object, output = object@output)
-})
\ No newline at end of file
+})
