@@ -23,7 +23,7 @@ sanitize_j <- function(j, x) {
 }
 
 sanitize_output <- function(output) {
-  assert_choice(output, choice = c("markdown", "latex", "html", "typst"), null.ok = TRUE)
+  assert_choice(output, choice = c("markdown", "latex", "html", "typst", "dataframe"), null.ok = TRUE)
 
   # default output format
   if (is.null(output)) {
@@ -37,7 +37,6 @@ sanitize_output <- function(output) {
   if (isTRUE(check_dependency("knitr"))) {
 
     if (isTRUE(knitr::pandoc_to() == "latex")) {
-      usepackage_latex("codehigh")
       usepackage_latex("float")
       usepackage_latex("tabularray", extra_lines = c(
         "\\usepackage[normalem]{ulem}",
